Sonar Blacktown, Australia September 18th 2006 2R+F 12 players Peter Rophail Protean-Dominate Stealth-Bleed Simple stealth-bleed with the added resilience provided by combat ends. Earth Meld greatly improves the deck's ability to block multiple actions while Form of Mist works extremely well as a block-deny mechanism. Crypt (12 cards, min=13, max=26, avg=5.17) ------------------------------------------ 3x Caitlin 6 ANI PRO aus dom bishop Gangrel antitribu:2 2x Iliana 7 DOM FOR PRO tha Gangrel:2 2x Horrock 6 ANI PRO vic Gangrel:3 2x Chandler Hungerford 3 PRO Gangrel:2 1x Dr. Allan Woodstock 5 PRO ani aus for Gangrel:3 1x Mirembe Kabbada 5 PRO SER ani Gangrel:2 1x Sadie 2 pro Gangrel antitribu:2 Library (90 cards) Master (18; 1 trifle) 1x Backways 4x Blood Doll 1x Campground Hunting Ground 1x Coven, The 4x Dominate 2x Ecoterrorists 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 1x Pentex(TM) Subversion 1x Rumor Mill, Tabloid Newspaper, The 1x Zoo Hunting Ground Action (6) 6x Govern the Unaligned Ally (3) 1x Carlton Van Wyk 2x Procurer Equipment (5) 3x Laptop Computer 1x Seal of Veddartha 1x Sport Bike Retainer (2) 1x J. S. Simmons, Esq. 1x Mr. Winthrop Action Modifier (9) 5x Conditioning 4x Earth Control Reaction (20) 8x Deflection 5x Sonar 7x Wake with Evening's Freshness Combat (26) 14x Earth Meld 12x Form of Mist Event (1) 1x Break the Code